@@ -20,7 +20,7 @@ no strict 'refs';
 
 my $regex;
 
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 our @EXPORT_OK
     = qw(get_all_postalcodes get_all_cities get_all_data create_regex validate_postalcode validate get_city_from_postalcode get_postalcode_from_city);
 
@@ -301,17 +301,9 @@ sub _build_tree {
 
 =end markdown
 
-=begin html
-
-<a href="http://badge.fury.io/pl/Business-DK-Postalcode"><img src="https://badge.fury.io/pl/Business-DK-Postalcode.svg" alt="CPAN version" height="18"></a>
-<a href="https://travis-ci.org/jonasbn/bdkpst.svg?branch=master"><img src="https://travis-ci.org/jonasbn/bdkpst.svg?branch=master" alt="Travil build status"></a>
-<a href="https://coveralls.io/r/jonasbn/bdkpst?branch=master"><img src="https://coveralls.io/repos/jonasbn/bdkpst/badge.png?branch=master"></a>
-
-=end html
-
 =head1 NAME
 
-Business::DK::Postalcode - validation and listing of Danish postal codes
+Business::DK::Postalcode - Danish postal code validator and container 
 
 =head1 VERSION
 
@@ -846,7 +838,7 @@ which could generate the pattern for me based on a finite data set.
 
 =head1 COPYRIGHT
 
-Business-DK-Postalcode is (C) by Jonas B. Nielsen, (jonasbn) 2006-2014
+Business-DK-Postalcode is (C) by Jonas B. Nielsen, (jonasbn) 2006-2015
 
 =head1 LICENSE
 
